Documentation
¶
Index ¶
- func CustomRole_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, ...) cdktf.ImportableResource
- func CustomRole_IsConstruct(x interface{}) *bool
- func CustomRole_IsTerraformElement(x interface{}) *bool
- func CustomRole_IsTerraformResource(x interface{}) *bool
- func CustomRole_TfResourceType() *string
- func NewCustomRolePolicyList_Override(c CustomRolePolicyList, terraformResource cdktf.IInterpolatingParent, ...)
- func NewCustomRolePolicyOutputReference_Override(c CustomRolePolicyOutputReference, ...)
- func NewCustomRolePolicyStatementsList_Override(c CustomRolePolicyStatementsList, terraformResource cdktf.IInterpolatingParent, ...)
- func NewCustomRolePolicyStatementsOutputReference_Override(c CustomRolePolicyStatementsOutputReference, ...)
- func NewCustomRole_Override(c CustomRole, scope constructs.Construct, id *string, config *CustomRoleConfig)
- type CustomRole
- type CustomRoleConfig
- type CustomRolePolicy
- type CustomRolePolicyList
- type CustomRolePolicyOutputReference
- type CustomRolePolicyStatements
- type CustomRolePolicyStatementsList
- type CustomRolePolicyStatementsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func CustomRole_GenerateConfigForImport ¶
func CustomRole_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, provider cdktf.TerraformProvider) cdktf.ImportableResource
Generates CDKTF code for importing a CustomRole resource upon running "cdktf plan <stack-name>".
func CustomRole_IsConstruct ¶
func CustomRole_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func CustomRole_IsTerraformElement ¶
func CustomRole_IsTerraformElement(x interface{}) *bool
Experimental.
func CustomRole_IsTerraformResource ¶
func CustomRole_IsTerraformResource(x interface{}) *bool
Experimental.
func CustomRole_TfResourceType ¶
func CustomRole_TfResourceType() *string
func NewCustomRolePolicyList_Override ¶
func NewCustomRolePolicyList_Override(c CustomRolePolicyList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewCustomRolePolicyOutputReference_Override ¶
func NewCustomRolePolicyOutputReference_Override(c CustomRolePolicyOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewCustomRolePolicyStatementsList_Override ¶
func NewCustomRolePolicyStatementsList_Override(c CustomRolePolicyStatementsList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewCustomRolePolicyStatementsOutputReference_Override ¶
func NewCustomRolePolicyStatementsOutputReference_Override(c CustomRolePolicyStatementsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewCustomRole_Override ¶
func NewCustomRole_Override(c CustomRole, scope constructs.Construct, id *string, config *CustomRoleConfig)
Create a new {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.17.0/docs/resources/custom_role launchdarkly_custom_role} Resource.
Types ¶
type CustomRole ¶
type CustomRole interface {
cdktf.TerraformResource
BasePermissions() *string
SetBasePermissions(val *string)
BasePermissionsInput() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
Description() *string
SetDescription(val *string)
DescriptionInput() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
Key() *string
SetKey(val *string)
KeyInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
Policy() CustomRolePolicyList
PolicyInput() interface{}
PolicyStatements() CustomRolePolicyStatementsList
PolicyStatementsInput() interface{}
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
// Adds a user defined moveTarget string to this resource to be later used in .moveTo(moveTarget) to resolve the location of the move.
// Experimental.
AddMoveTarget(moveTarget *string)
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
HasResourceMove() interface{}
// Experimental.
ImportFrom(id *string, provider cdktf.TerraformProvider)
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Move the resource corresponding to "id" to this resource.
//
// Note that the resource being moved from must be marked as moved using it's instance function.
// Experimental.
MoveFromId(id *string)
// Moves this resource to the target resource given by moveTarget.
// Experimental.
MoveTo(moveTarget *string, index interface{})
// Moves this resource to the resource corresponding to "id".
// Experimental.
MoveToId(id *string)
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutPolicy(value interface{})
PutPolicyStatements(value interface{})
ResetBasePermissions()
ResetDescription()
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetPolicy()
ResetPolicyStatements()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.17.0/docs/resources/custom_role launchdarkly_custom_role}.
func NewCustomRole ¶
func NewCustomRole(scope constructs.Construct, id *string, config *CustomRoleConfig) CustomRole
Create a new {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.17.0/docs/resources/custom_role launchdarkly_custom_role} Resource.
type CustomRoleConfig ¶
type CustomRoleConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// A unique key that will be used to reference the custom role in your code.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.17.0/docs/resources/custom_role#key CustomRole#key}
Key *string `field:"required" json:"key" yaml:"key"`
// A name for the custom role.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.17.0/docs/resources/custom_role#name CustomRole#name}
Name *string `field:"required" json:"name" yaml:"name"`
// The base permission level - either reader or no_access. Defaults to reader.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.17.0/docs/resources/custom_role#base_permissions CustomRole#base_permissions}
BasePermissions *string `field:"optional" json:"basePermissions" yaml:"basePermissions"`
// Description of the custom role.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.17.0/docs/resources/custom_role#description CustomRole#description}
Description *string `field:"optional" json:"description" yaml:"description"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.17.0/docs/resources/custom_role#id CustomRole#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// policy block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.17.0/docs/resources/custom_role#policy CustomRole#policy}
Policy interface{} `field:"optional" json:"policy" yaml:"policy"`
// policy_statements block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.17.0/docs/resources/custom_role#policy_statements CustomRole#policy_statements}
PolicyStatements interface{} `field:"optional" json:"policyStatements" yaml:"policyStatements"`
}
type CustomRolePolicy ¶
type CustomRolePolicy struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.17.0/docs/resources/custom_role#actions CustomRole#actions}.
Actions *[]*string `field:"required" json:"actions" yaml:"actions"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.17.0/docs/resources/custom_role#effect CustomRole#effect}.
Effect *string `field:"required" json:"effect" yaml:"effect"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.17.0/docs/resources/custom_role#resources CustomRole#resources}.
Resources *[]*string `field:"required" json:"resources" yaml:"resources"`
}
type CustomRolePolicyList ¶
type CustomRolePolicyList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) CustomRolePolicyOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewCustomRolePolicyList ¶
func NewCustomRolePolicyList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) CustomRolePolicyList
type CustomRolePolicyOutputReference ¶
type CustomRolePolicyOutputReference interface {
cdktf.ComplexObject
Actions() *[]*string
SetActions(val *[]*string)
ActionsInput() *[]*string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Effect() *string
SetEffect(val *string)
EffectInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
Resources() *[]*string
SetResources(val *[]*string)
ResourcesInput() *[]*string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewCustomRolePolicyOutputReference ¶
func NewCustomRolePolicyOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) CustomRolePolicyOutputReference
type CustomRolePolicyStatements ¶
type CustomRolePolicyStatements struct {
// Either `allow` or `deny`.
//
// This argument defines whether the statement allows or denies access to the named resources and actions.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.17.0/docs/resources/custom_role#effect CustomRole#effect}
Effect *string `field:"required" json:"effect" yaml:"effect"`
// The list of action specifiers defining the actions to which the statement applies.
//
// Either `actions` or `not_actions` must be specified. For a list of available actions read [Actions reference](https://docs.launchdarkly.com/home/account-security/custom-roles/actions#actions-reference).
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.17.0/docs/resources/custom_role#actions CustomRole#actions}
Actions *[]*string `field:"optional" json:"actions" yaml:"actions"`
// The list of action specifiers defining the actions to which the statement does not apply.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.17.0/docs/resources/custom_role#not_actions CustomRole#not_actions}
NotActions *[]*string `field:"optional" json:"notActions" yaml:"notActions"`
// The list of resource specifiers defining the resources to which the statement does not apply.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.17.0/docs/resources/custom_role#not_resources CustomRole#not_resources}
NotResources *[]*string `field:"optional" json:"notResources" yaml:"notResources"`
// The list of resource specifiers defining the resources to which the statement applies.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.17.0/docs/resources/custom_role#resources CustomRole#resources}
Resources *[]*string `field:"optional" json:"resources" yaml:"resources"`
}
type CustomRolePolicyStatementsList ¶
type CustomRolePolicyStatementsList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) CustomRolePolicyStatementsOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewCustomRolePolicyStatementsList ¶
func NewCustomRolePolicyStatementsList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) CustomRolePolicyStatementsList
type CustomRolePolicyStatementsOutputReference ¶
type CustomRolePolicyStatementsOutputReference interface {
cdktf.ComplexObject
Actions() *[]*string
SetActions(val *[]*string)
ActionsInput() *[]*string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Effect() *string
SetEffect(val *string)
EffectInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
NotActions() *[]*string
SetNotActions(val *[]*string)
NotActionsInput() *[]*string
NotResources() *[]*string
SetNotResources(val *[]*string)
NotResourcesInput() *[]*string
Resources() *[]*string
SetResources(val *[]*string)
ResourcesInput() *[]*string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetActions()
ResetNotActions()
ResetNotResources()
ResetResources()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewCustomRolePolicyStatementsOutputReference ¶
func NewCustomRolePolicyStatementsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) CustomRolePolicyStatementsOutputReference
Source Files
¶
- CustomRole.go
- CustomRoleConfig.go
- CustomRolePolicy.go
- CustomRolePolicyList.go
- CustomRolePolicyList__checks.go
- CustomRolePolicyOutputReference.go
- CustomRolePolicyOutputReference__checks.go
- CustomRolePolicyStatements.go
- CustomRolePolicyStatementsList.go
- CustomRolePolicyStatementsList__checks.go
- CustomRolePolicyStatementsOutputReference.go
- CustomRolePolicyStatementsOutputReference__checks.go
- CustomRole__checks.go
- main.go